@@ -4,4 +4,8 @@ from .mc import *
 from .gohmm import *
 from .mdp import *
 from .ctmc import *
-from .mgohmm import *
\ No newline at end of file
+from .mgohmm import *
+try:
+	from .with_stormpy import *
+except ModuleNotFoundError:
+	print("Stormpy not found.")
\ No newline at end of file
